  t.event<-summary(survfit(S~1))$time
  Lost<-Surv(analysis$fup24mo,analysis$ltfu24mo)
  ## MODEL TIME TO LOST USING SAME COVARIATES AS TIME TO DEATH
  modLost <- fit.mult.impute(Lost~districts+Sex+rcs(Age,4)+Maritalstatus+Education+ReferralType+EnrollBMI+rcs(sqrt(txcd4),4)+txstage+txhem+D4T+rcs(FIRSTPHARM,5), cph, surv=T, imp.g1, d.g1)
  pred.lost<-predict(modLost)
  ## USE MODEL TO PREDICT HAZARD OF BEING LOST FOR EACH INDIVIDUAL (PARTIAL LIKELIHOOD ESTIMATOR)
  
  ## THIS IS SLIGHTLY MODIFIED FROM MANUSCRIPT - MANUSCRIPT RECOMMENDED 1-(1-surv)exp(pred.lost)
  kc.bry<-kronecker(t(modLost$surv),exp(pred.lost),FUN="^")
  kc.man<-1-kronecker(t(1-modLost$surv),exp(pred.lost),FUN="^")
  kc <- kc.bry
  t.lost<-modLost$time

  n.risk<-n.event<-NULL
  ## IF NO PERSON IS LOST PRIOR TO FIRST EVENT THEN NORMAL (NO WEIGHTING)
  if (sum(t.lost<t.event[1])==0) {
    n.event[1]<-sum(analysis$death24mo*(analysis$fup24mo<=t.event[1]))
    n.risk[1]<-sum(analysis$fup24mo>=t.event[1])
  }
  ## IF ONE OR MORE PERSONS IS LOST PRIOR TO FIRST EVENT THEN USE IPCW 
  if (sum(t.lost<t.event[1])>0) {
    locate<-which(t.lost==max(t.lost[t.lost<t.event[1]]))
    n.event[1]<-sum(analysis$death24mo*(analysis$fup24mo<=t.event[1])/kc[,locate])
    n.risk[1]<-sum((analysis$fup24mo>=t.event[1])/kc[,locate])
  }
  for (j in 2:length(t.event)) {
    locate<-which(t.lost==max(t.lost[t.lost<t.event[j]])) 
    n.event[j]<-sum(analysis$death24mo*(analysis$fup24mo<=t.event[j]&analysis$fup24mo>t.event[j-1])/kc[,locate])
    n.risk[j]<-sum((analysis$fup24mo>=t.event[j])/kc[,locate])
  }
  ## THIS IS THE IPCW KAPLAN-MEIER ESTIMATOR
  Shat<-c(1,cumprod(1-n.event/n.risk))


max(1-summary(survfit(S~1))$surv)
max(1-Shat)                                          
   

######  Creating Kaplan-Meier survival figure after adjusting for baseline covariates -- not included in manuscript
t.event<-c(summary(survfit(S~1))$time)
png(file="graphics/KM_IPCW_Mortality.png", bg="transparent", width=1200, height=1200, res=200) 
    par(mfrow=c(1,1))
    plot(survfit(S~1),xlab="Time (months)",ylab="Probability of Death",axes=FALSE,conf.int=FALSE,mark.time=FALSE,
	ylim=c(0,0.165),xlim=c(0,730), xmax=730,fun="event",col=4,lwd=2)
    box()
    axis(side=2)
    axis(side=1,at=(730*c(0,.25,.5,.75,1)),labels=c(0,6,12,18,24))
lines(c(t.event,730),1-Shat,lty=2,col=4,xlim=c(0,730))
    legend(95,.16,c("Original","IPCW"),col=c(4),
 	  lwd=c(2,1),lty=c(1,2),bty="n",cex=.8)
dev.off()


