  
#############################################################
#
#   Program: nomogram_corrected.R
#	  
#   Project: ART in rural Mozambique: 2 year outcomes 
# 
#   PI: 
#       Mohsin Sidat, MD, PhD
#       Alfredo Vergara, PhD
# 	 Sten Vermund, MD, PhD
#	 Troy Moon, MD, MPH*
#       * corresponding author, troy.moon at fgh.org.mz
#	  
#   Biostatistician/Programmer: Meridith Blevins, MS**
#   ** contact programmer: meridith.blevins at vanderbilt.edu
#	  
#   Statistician: Bryan E Shepherd, PhD
#	  
#   Purpose: Reproducible research.
#	      
#   Notes: http://www.iedea-sa.org/index.php?id=2743
#          
#   Created: 11 January 2012
#	  
#   Revisions: 
#   
#
#############################################################

#'GNU S' R Code compiled by R2WASP v. 1.0.44 ()
#To cite this work: Martin WG Brinkhof, Ben D Spycher, 2010, Correcting Mortality Estimates for Loss to Follow-up in sub-Saharan African ART Programmes (v1.0) in Free Statistics Software (v1.1.23), Office for Research Development and Education, URL http://www.wessa.net/rwasp_mortality_mc.wasp/
#Source of accompanying publication: Egger M, Spycher BD, et al. under review (source updated ASAP).
#Technical description: 

S_nltfu <- (100-M_nltfu)/100 # estimated survival at 1 year from a Kaplan Meier
S_nltfu_lb <- (100-M_nltfu_ub)/100	# 95%CI lower bound
S_nltfu_ub <- (100-M_nltfu_lb)/100 	# 95%CI upper bound

n_rep<-10^5
set.seed(12345)
beta<-as.vector(c(-.04044087,.57287318))
V<-rbind(c(.00021312,-.0044198),c(-.0044198,.12357747))
tau2<-.3682446984157812
seu_S_nltfu<-as.numeric((log(-log(S_nltfu))-log(-log(S_nltfu_ub)))/1.96)
sel_S_nltfu<-as.numeric((log(-log(S_nltfu_lb))-log(-log(S_nltfu)))/1.96)
se_S_nltfu<-mean(c(seu_S_nltfu,sel_S_nltfu))
m_S_nltfu<-as.numeric(log(-log(S_nltfu)))
dev_S_nltfu<-rnorm(n_rep, mean = m_S_nltfu, sd = se_S_nltfu)
dev_S_nltfu<-exp(-exp(dev_S_nltfu))
dev_R_ltfu<-rbinom(n_rep, N_ltfu, n_ltfu/N_ltfu)/N_ltfu
x_val<-cbind(100*dev_R_ltfu,1) 	# percent LTFU
sd_M_ltfu<-sqrt(apply((x_val%*%V)*x_val,1,sum)+tau2)
m_M_ltfu<-x_val%*%beta
logitM_ltfu<-rnorm(rep(1,n_rep),mean=m_M_ltfu, sd=sd_M_ltfu)
dev_M_ltfu<-1/(1+exp(-logitM_ltfu))
dev_M_corr<-(1-dev_R_ltfu)*(1-dev_S_nltfu)+dev_R_ltfu*dev_M_ltfu
M_corr<-mean(dev_M_corr)*100
M_corr_ci<-quantile(dev_M_corr,c(0.025,0.975))*100
M_corr
M_corr_ci


